@@ -3,7 +3,7 @@
 # Business::Bitcoin - Easy and secure way to accept Bitcoin payments online
 # Copyright (c) 2016-2017 Ashish Gulhati <biz-btc at hash dot neomailbox.ch>
 #
-# $Id: lib/Business/Bitcoin.pm v1.027 Sun Jan 22 07:57:50 PST 2017 $
+# $Id: lib/Business/Bitcoin.pm v1.028 Sun Jan 22 10:34:32 PST 2017 $
 
 use strict;
 
@@ -18,14 +18,14 @@ use Business::Bitcoin::Request;
 
 use vars qw( $VERSION $AUTOLOAD );
 
-our ( $VERSION ) = '$Revision: 1.027 $' =~ /\s+([\d\.]+)/;
+our ( $VERSION ) = '$Revision: 1.028 $' =~ /\s+([\d\.]+)/;
 
 sub new {
   my $class = shift;
   my %args = @_;
   return undef unless $args{XPUB};
   return undef if $args{StartIndex} and $args{StartIndex} =~ /\D/;
-  unlink $args{DB} if $args{Clobber};
+  unlink $args{DB} if $args{Clobber} and $args{DB} ne ':memory:';
   my $db = DBI->connect("dbi:SQLite:dbname=$args{DB}", undef, undef, {AutoCommit => 1});
   my @tables = $db->tables('%','%','requests','TABLE');
   unless ($tables[0]) {
@@ -90,8 +90,8 @@ Business::Bitcoin - Easy and secure way to accept Bitcoin payments online
 
 =head1 VERSION
 
- $Revision: 1.027 $
- $Date: Sun Jan 22 07:57:50 PST 2017 $
+ $Revision: 1.028 $
+ $Date: Sun Jan 22 10:34:32 PST 2017 $
 
 =head1 SYNOPSIS
 
